#ifndef __DRIVER_ESB_H__
#define __DRIVER_ESB_H__

//==============================================================================
// LIB
#include <stdint.h>

// OS
#include <zephyr/types.h>
#include <esb.h>

// APP
// -
// *****************************************************************************
//                          Test management directives
#define TEST_DRV_ESB_EVENT_RX_PRINT     0                   /* enable/disable - parameter printing in drv_esb_init() - destructive for ESB RX*/
#define TEST_DRV_ESB_INIT_PARAM_PRINT   1                   /* enable/disable - parameter printing in drv_esb_init() */
// *****************************************************************************
#define DRV_ESB_RX_DATA_FIFO_PUT 1                          /* enable/disable - inserting received ESB into FIFO in drv_esb_event_handler() */
//==============================================================================

//==============================================================================
//      						Constatnts and parameters
// *****************************************************************************
#define _RADIO_SHORTS_COMMON                                            \
	(RADIO_SHORTS_READY_START_Msk | RADIO_SHORTS_END_DISABLE_Msk |      \
	 RADIO_SHORTS_ADDRESS_RSSISTART_Msk |                               \
	 RADIO_SHORTS_DISABLED_RSSISTOP_Msk)
//------------------------------------------------------------------------------
#define ESB_BASE_ADDR0_SIZE 4
#define ESB_BASE_ADDR1_SIZE 4
#define ESB_PREFIX_SIZE 8
//------------------------------------------------------------------------------
//#define ESB_NOACK_
//==============================================================================
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 

// #############################################################################
//              				Makros and definitions
// #############################################################################


// *****************************************************************************
// 						Defining enumerators and structures
// *****************************************************************************
// Structure for ESB states variables - it is OK when we have only one instance
/*typedef struct ESBstates{
    bool tx_ready;                      // indication that ESB is ready to transmit
} ESBstates_t;
*/
//------------------------------------------------------------------------------
// Structure for ESB instance
typedef struct ESBcontrol{
    bool tx_ready;                      // indication that ESB is ready to transmit
    struct k_sem * tx_sem_ptr;          // pointer to semaphore used to wait for each TX to complete.
    struct k_fifo * rx_fifo_ptr;        // pointer to FIFO used to sendint the ESB packet from handler service 
    bool ack_enable;                    //  0/1 ~ disable/enable acknowledgement

} ESBcontrol_t;
//------------------------------------------------------------------------------
// Structure for ESB configuration
typedef struct ESBconfig{
    const uint8_t * base_addr_0_ptr;    // pointer to ESB base address 0
    uint8_t * base_addr_1_ptr;          // pointer to ESB base address 1
    uint8_t * addr_prefix_ptr;          // pointer to ESB address prexix
    enum esb_mode mode;			        /**< Mode. */
    bool ack_enable;                    //  0/1 ~ disable/enable acknowledgement

} ESBconfig_t;
//------------------------------------------------------------------------------
// Data structure to enqueue
struct data_esb_item_t {
    void *fifo_reserved;  									// 1st word reserved for use by FIFO
	int read_status;						 				// return value from reading f-ction from esb_event handler - first initialization
    struct esb_payload payload;
};
// *****************************************************************************
// 								Publishing global variables
// *****************************************************************************
// memory region:                   DATA
// *****************************************************************************

// *****************************************************************************
// memory region:            		CODE
// *****************************************************************************

// *****************************************************************************
//                             Function prototypes
// *****************************************************************************
int drv_esb_init(ESBcontrol_t * esb_ptr, ESBconfig_t * esb_cfg);


// ******************************************************************bookmark***

#endif /* __DRIVER_ESB_H__ */
